From 57dce3c68fb63403be15e20f769ba7c38ba26537 Mon Sep 17 00:00:00 2001
From: "Sridhar K. N. Rao" <sridhar.rao@spirent.com>
Date: Fri, 30 Aug 2019 00:48:32 +0530
Subject: Python: Upgrade Python version from 3.4 to 3.6

This patch upgrade python version from 3.4 to 3.6 for the following
systems.
Centos
rhel - 7.2, 7.3 and 7.5
ubuntu
For fedora and opensuse - no specific option available.
SLES is already using 3.6

Signed-off-by: Sridhar K. N. Rao <sridhar.rao@spirent.com>
Change-Id: Ib1a1cb04441c8fe53339f7f9a66e0266d6ceefe0
---
 systems/rhel/7.2/build_base_machine.sh | 10 +++++-----
 systems/rhel/7.2/prepare_python_env.sh |  4 ++--
 2 files changed, 7 insertions(+), 7 deletions(-)

(limited to 'systems/rhel/7.2')

diff --git a/systems/rhel/7.2/prepare_python_env.sh b/systems/rhel/7.2/prepare_python_env.sh
index 047d6961..b7506568 100755
--- a/systems/rhel/7.2/prepare_python_env.sh
+++ b/systems/rhel/7.2/prepare_python_env.sh
@@ -21,8 +21,8 @@ if [ -d "$VSPERFENV_DIR" ] ; then
     exit
 fi
 
-scl enable rh-python34 "
-virtualenv "$VSPERFENV_DIR" --python /opt/rh/rh-python34/root/usr/bin/python3
+scl enable rh-python36 "
+virtualenv "$VSPERFENV_DIR" --python /opt/rh/rh-python36/root/usr/bin/python3
 source "$VSPERFENV_DIR"/bin/activate
 pip install -r ../requirements.txt
 "
diff --git a/systems/rhel/7.2/build_base_machine.sh b/systems/rhel/7.2/build_base_machine.sh
index 198f39d7..c0f367ab 100755
--- a/systems/rhel/7.2/build_base_machine.sh
+++ b/systems/rhel/7.2/build_base_machine.sh
@@ -93,14 +93,14 @@ enabled=1
 gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-SCLo
 EOT
 
 # install python34 packages and git-review tool
 yum -y install $(echo "
-rh-python34
-rh-python34-python-tkinter
+rh-python36
+rh-python36-python-tkinter
 " | grep -v ^#)
 
-# cleanup python 34 repo file
-rm -f /etc/yum.repos.d/python34.repo
+# cleanup python 36 repo file
+rm -f /etc/yum.repos.d/python36.repo
 
 # Create hugepage dirs
 mkdir -p /dev/hugepages
@@ -93,14 +93,14 @@ enabled=1
 EOT
 
-# install python34 packages and git-review tool
+# install python36 packages and git-review tool
 yum -y install $(echo "
-- 
cgit